@@ -1,12 +1,11 @@
 import pandas as pd
-import numpy as np
-import matplotlib
 import matplotlib.pyplot as plt
 import seaborn as sns
 import math
 import plotly.graph_objects as go
 
 def prep_dataframe(file):
+    pd.set_option('display.float_format', lambda x: '%.2f' % x)
     statement = pd.read_csv(file)
     statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
     statement.Breakdown = statement.Breakdown.str.replace(',', '')
@@ -18,7 +17,6 @@ def prep_dataframe(file):
 
 
 def printStatement(file):
-    pd.set_option('display.float_format', lambda x: '%.2f' % x)
     statement = prep_dataframe(file)
     print(statement)
 
@@ -134,3 +132,15 @@ def bulletChart(file,item):
     
     fig.show()
 
+def horizontalAnalysisLastTwo(file):
+    statement = prep_dataframe(file)
+    statement = statement.reindex(sorted(statement.columns), axis=1)
+    statement_lastPeriods = statement[statement.columns[-2:]]
+    statement_lastPeriods_lastColName = statement[statement_lastPeriods.columns[-1:]].columns.values[0]
+    statement_lastPeriods_secondLastColName = statement[statement_lastPeriods.columns[-2:-1]].columns.values[0]
+    statement_lastPeriods['Amount(Increased/Decreased)'] = statement_lastPeriods[statement_lastPeriods_lastColName]-statement_lastPeriods[statement_lastPeriods_secondLastColName]
+    statement_lastPeriods['Percentage(Increased/Decreased)'] = (statement_lastPeriods[statement_lastPeriods_lastColName]/statement_lastPeriods[statement_lastPeriods_secondLastColName])-1
+    statement_lastPeriods = statement_lastPeriods.dropna()
+    statement_lastPeriods['Percentage(Increased/Decreased)'] = pd.Series(["{0:.2f}%".format(val * 100) for val in statement_lastPeriods['Percentage(Increased/Decreased)']], index = statement_lastPeriods.index)
+    statement_lastPeriods.to_csv('horizontalAnalysisLastTwo.csv')
+    print("Horizontal Analysis with Last two Periods", statement_lastPeriods, sep='\n')
